==> net.sf.amateras.air_1.0.0.jar: src/net/sf/amateras/air/mxml/models/AbstractScrollControllBase.java <==
package net.sf.amateras.air.mxml.models;

/**
 * model of mx.core.ScrollControllBase
 * @author ogawahideko
 *
 */
public abstract class AbstractScrollControllBase extends AbstractComponentModel {
	//properties
	public static final String HORIZONTAL_SCROLL_POLICY = "horizontalScrollPolicy";
	public static final String HORIZONTAL_SCROLL_POSITION = "horizontalScrollPosition";

	public static final String VERTICAL_SCROLL_POLICY = "verticalScrollPolicy";
	public static final String VERTICAL_SCROLL_POSITION = "verticalScrollPosition";

	//styles
	public static final String FONT_FAMILY = "fontFamily";
	public static final String FONT_SIZE = "fontSize";
	public static final String FONT_STYLE = "fontStyle";
	public static final String FONT_WEIGHT = "fontWeight";

	@Override
	protected void installModelProperty() {
		super.installModelProperty();

		addListModelProperty(HORIZONTAL_SCROLL_POLICY, CATEGORY_PROPERTY, new String[] { "off",
				"on", "auto" });
		addNumberModelProperty(HORIZONTAL_SCROLL_POSITION, CATEGORY_PROPERTY, 0);

		addListModelProperty(VERTICAL_SCROLL_POLICY, CATEGORY_PROPERTY, new String[] { "auto",
				"on", "off" });
		addNumberModelProperty(VERTICAL_SCROLL_POSITION, CATEGORY_PROPERTY, 0);

		addStringModelProperty(FONT_FAMILY, CATEGORY_STYLE, "Verdana");
		addNumberModelProperty(FONT_SIZE, CATEGORY_STYLE, 10);
		addListModelProperty(FONT_STYLE, CATEGORY_STYLE, new String[] { "normal", "italic" });
		addListModelProperty(FONT_WEIGHT, CATEGORY_STYLE, new String[] { "normal", "bold" });

	}
}

==> net.sf.amateras.air_1.0.3.jar: src/net/sf/amateras/air/mxml/models/AbstractScrollControllBase.java <==
package net.sf.amateras.air.mxml.models;

/**
 * model of mx.core.ScrollControllBase
 * @author ogawahideko
 *
 */
public abstract class AbstractScrollControllBase extends AbstractComponentModel {
	//properties
	public static final String HORIZONTAL_SCROLL_POLICY = "horizontalScrollPolicy";
	public static final String HORIZONTAL_SCROLL_POSITION = "horizontalScrollPosition";

	public static final String VERTICAL_SCROLL_POLICY = "verticalScrollPolicy";
	public static final String VERTICAL_SCROLL_POSITION = "verticalScrollPosition";

	//styles
	public static final String FONT_FAMILY = "fontFamily";
	public static final String FONT_SIZE = "fontSize";
	public static final String FONT_STYLE = "fontStyle";
	public static final String FONT_WEIGHT = "fontWeight";

	@Override
	protected void installModelProperty() {
		super.installModelProperty();

		addListModelProperty(HORIZONTAL_SCROLL_POLICY, CATEGORY_PROPERTY, new String[] { "off", "on", "auto" });
		addNumberModelProperty(HORIZONTAL_SCROLL_POSITION, CATEGORY_PROPERTY, 0);

		addListModelProperty(VERTICAL_SCROLL_POLICY, CATEGORY_PROPERTY, new String[] { "auto", "on", "off" });
		addNumberModelProperty(VERTICAL_SCROLL_POSITION, CATEGORY_PROPERTY, 0);

		addStringModelProperty(FONT_FAMILY, CATEGORY_STYLE, "Verdana");
		addNumberModelProperty(FONT_SIZE, CATEGORY_STYLE, 10);
		addListModelProperty(FONT_STYLE, CATEGORY_STYLE, new String[] { "normal", "italic" });
		addListModelProperty(FONT_WEIGHT, CATEGORY_STYLE, new String[] { "normal", "bold" });

	}
}
